
dialogId("sl-v-stopa", "font_big", "I think that we are finally on the trail of that mysterious city.")

dialogId("sl-m-velkolepe", "font_small", "It looks magnificent.")

dialogId("sl-v-vkapse", "font_big", "Now we only have to find out why it sank and we are done.")

dialogId("sl-m-trvat", "font_small", "But it may take us a little while.")

dialogId("sl-v-nechme", "font_big", "Leave me alone. I adore the classic beauty of this temple.")

dialogId("sl-m-sedi", "font_small", "Who is sitting on that chair?")

dialogId("sl-v-feidios", "font_big", "It’s a copy of Feidios’ Zeus. One of the seven wonders of the world.")

dialogId("sl-m-tehdy", "font_small", "Hmm. It was another age.")

dialogId("sl-v-opatrne", "font_big", "Be careful! Try not to damage it!")

dialogId("sl-v-skoda", "font_big", "Such a waste!")

dialogId("sl-v-pust", "font_big", "And now ease it down, carefully.")

dialogId("sl-m-jekot", "", "")

dialogId("sl-v-barbarka", "font_big", "You barbarian! Can’t you be a little bit cautious?!")

dialogId("sl-m-nelibila", "font_small", "I didn’t like this sculpture anyway.")
